#ifndef cxxtls_excel_header_included_p
#define cxxtls_excel_header_included_p
#include <string>
///@file
///
///  This file defines two functions which allow for the bidirectional conversion between integers
///  and excel column header names.  
///
///  @see excel2decimal @br
///  @see decimal2excel
///
namespace cxxtls
{
   extern int          excel2decimal(char const *columnTitleName);   
                                                                     ///<  convert a column header name into
                                                                     ///   into an integer.
                                                                     ///
                                                                     ///  @param columnTitleName a sequence of
                                                                     ///         characters in the range 'A' to
                                                                     ///         'Z'.  For example, 'A' is 1,
                                                                     ///         and 'Z' is 26.  'AA' is 27, etc.
                                                                     ///
                                                                     ///  @return the corresponding integer.

   inline int          excel2decimal(std::string const &columnTitle) 
       /// @copydoc excel2decimal(char const *);
   { 
       return excel2decimal(columnTitle.c_str()); 
   }
   extern std::string  decimal2excel(int value);  ///<  Convert an integer to an excel column header name.
                                                  ///   @param[i] value  A positive, non-zero integer.
                                                  ///
                                                  ///   @return a std::string containing the corresponding
                                                  ///   excel column header name:  1='A', 26='Z', 27='AA',
                                                  ///   etc.
}
#endif
